Coverage for /media/ldata/code/tendril/tendril/frontend/blueprints/customs/views.py: 0%

# Coverage for /media/ldata/code/tendril/tendril/frontend/blueprints/customs/views.py : 0%

## 26 statements 0 run 26 missing 0 excluded

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 | #!/usr/bin/env python # encoding: utf-8 # Copyright (C) 2015 Chintalagiri Shashank # # This file is part of tendril. # # This program is free software: you can redistribute it and/or modify # it under the terms of the GNU Affero General Public License as published by # the Free Software Foundation, either version 3 of the License, or # (at your option) any later version. # # This program is distributed in the hope that it will be useful, # but WITHOUT ANY WARRANTY; without even the implied warranty of # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the # GNU Affero General Public License for more details. # # You should have received a copy of the GNU Affero General Public License # along with this program. If not, see <http://www.gnu.org/licenses/>. """ Docstring for views """ from flask import render_template from flask_user import login_required from . import customs as blueprint from tendril.dox import customs as dxcustoms from tendril.dox import docstore from tendril.entityhub import serialnos from tendril.utils.fsutils import Crumb @blueprint.route('/invoice/<invoice_sno>') @blueprint.route('/invoice/') @login_required def invoices(invoice_sno=None): if invoice_sno is None: snos = dxcustoms.get_all_customs_invoice_serialnos() stage = {'snos': snos, 'crumbroot': '/sourcing', 'breadcrumbs': [Crumb(name="Sourcing", path="main.html"), Crumb(name="Customs", path="customs/"), Crumb(name="Invoices", path="customs/inv/")], } return render_template('customs_invoices.html', stage=stage, pagetitle="Customs Document Sets") else: sno = serialnos.get_serialno_object(sno=invoice_sno) docs = docstore.get_docs_list_for_serialno(invoice_sno) invoice = dxcustoms.get_customs_invoice(invoice_sno) stage = {'sno': sno, 'docs': docs, 'invoice': invoice, 'crumbroot': '/sourcing', 'breadcrumbs': [Crumb(name="Sourcing", path="main.html"), Crumb(name="Customs", path="customs/"), Crumb(name="Invoices", path="customs/invoice/"), # noqa Crumb(name=invoice_sno, path="customs/invoice/" + invoice_sno)], # noqa } return render_template( 'customs_invoice_detail.html', stage=stage, pagetitle=invoice_sno + " Customs Document Set" ) @blueprint.route('/') @login_required def main(): latest = dxcustoms.get_all_customs_invoice_serialnos(limit=5) stage = {'latest': latest, 'crumbroot': '/sourcing', 'breadcrumbs': [Crumb(name="Sourcing", path="main.html"), Crumb(name="Customs", path="customs/")], } return render_template('customs_main.html', stage=stage, pagetitle='Customs')